@@ -1,6 +1,6 @@
 package Tcl;
 
-$Tcl::VERSION = '0.98';
+$Tcl::VERSION = '0.99';
 $Tcl::STACK_TRACE = 1;
 
 =head1 NAME
@@ -128,7 +128,10 @@ code as:
   my $r = 'aaaa';
   button(".d", -textvariable => \$r, -command=>sub {$r++});
 
-3.  As a special case, there is a mechanism to deal with Tk's special event
+3. All references to hashes will be substituted with names of Tcl array
+variables transformed appropriately.
+
+4.  As a special case, there is a mechanism to deal with Tk's special event
 variables (they are mentioned as '%x', '%y' and so on throughout Tcl).
 When creating a subroutine reference that uses such variables, you must
 declare the desired variables using Tcl::Ev as the first argument to the
@@ -299,7 +302,7 @@ To tie a Perl scalar I<$scalar> to the Tcl variable I<tclscalar> in
 interpreter I<$interp> with optional flags I<$flags> (see I<SetVar>
 above), use
 
-	tie $scalar, Tcl::Var, $interp, "tclscalar", $flags;
+	tie $scalar, "Tcl::Var", $interp, "tclscalar", $flags;
 
 Omit the I<$flags> argument if not wanted.
 
@@ -307,7 +310,7 @@ To tie a Perl hash I<%hash> to the Tcl array variable I<array> in
 interpreter I<$interp> with optional flags I<$flags>
 (see I<SetVar> above), use
 
-	tie %hash, Tcl::Var, $interp, "array", $flags;
+	tie %hash, "Tcl::Var", $interp, "array", $flags;
 
 Omit the I<$flags> argument if not wanted. Any alteration to Perl
 variable I<$hash{"key"}> affects the Tcl variable I<array(key)>
@@ -494,6 +497,25 @@ sub call {
 	    }
 	    $args[$argcnt] = $nm; # ... and substitute its name
 	}
+	elsif ($ref eq 'HASH') {
+	    # We have been passed something like \%hash
+	    # Create a tied variable between Tcl and Perl.
+
+	    # stringify hash ref, create in ::perl namespace on Tcl side
+	    # This will be HASH(0xXXXXXX) - leave it to become part of a
+	    # Tcl array.
+	    my $nm = $arg;
+	    $nm =~ s/\W/_/g; # remove () from stringified name
+	    $nm = "::perl::$nm";
+	    unless (exists $anon_refs{$nm}) {
+		$widget_refs{$current_widget}->{$nm}++;
+		$anon_refs{$nm} = $arg;
+		my %s = %$arg;
+		tie %$arg, 'Tcl::Var', $interp, $nm;
+		%$arg = %s;
+	    }
+	    $args[$argcnt] = $nm; # ... and substitute its name
+	}
 	elsif ($ref eq 'ARRAY' && ref($arg->[0]) eq 'CODE') {
 	    # We have been passed something like [\&subroutine, $arg1, ...]
 	    # Create a proc in Tcl that invokes this subroutine with args
